Daemon rucio-light-reaper — Rucio 1.2 documentation

# Daemon rucio-light-reaper

    usage: rucio-light-reaper [-h] [--run-once] [--all-rses]
                              [--total-workers TOTAL_WORKERS]
                              [--chunk-size CHUNK_SIZE] [--scheme SCHEME]
                              [--rses RSES [RSES ...]]

## Named Arguments

`--run-once` | One iteration only Default: False
`--all-rses` | Select RSEs from the quarantined queues Default: False
`--total-workers`
| Total number of workers per process Default: 1
`--chunk-size` | Chunk size Default: 10
`--scheme` | Force the reaper to use a particular protocol, e.g., mock.
`--rses` | List of RSEs